@@ -22,8 +22,6 @@
 
 #include <cuda/std/__type_traits/remove_reference.h>
 
-#include <cuda/std/__cccl/prologue.h>
-
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
 template <class _Tp>
@@ -31,6 +29,4 @@ using __make_const_lvalue_ref = const remove_reference_t<_Tp>&;
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
-#include <cuda/std/__cccl/epilogue.h>
-
 #endif // _LIBCUDACXX___TYPE_TRAITS_MAKE_CONST_LVALUE_REF_H
