@@ -24,8 +24,6 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 """
-from __future__ import annotations
-
 
 import warnings
 
@@ -192,7 +190,7 @@ extern "C" __global__ void __launch_bounds__( 512 ) _cupy_lombscargle_float64(
 
 
 LOMBSCARGLE_MODULE = cupy.RawModule(
-    code=LOMBSCARGLE_KERNEL,
+    code=LOMBSCARGLE_KERNEL, options=('-std=c++11',),
     name_expressions=['_cupy_lombscargle_float32',
                       '_cupy_lombscargle_float64'])
 
@@ -327,7 +325,7 @@ def _spectral_helper(
 
     if boundary not in boundary_funcs:
         raise ValueError(
-            "Unknown boundary option '{}', must be one of: {}".format(
+            "Unknown boundary option '{0}', must be one of: {1}".format(
                 boundary, list(boundary_funcs.keys())
             )
         )
